==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Vidi la diferencojn',

	// D
	'diff_para_ajoute' => 'Paragrafo aldonita',
	'diff_para_deplace' => 'Paragrafo translokita',
	'diff_para_supprime' => 'Paragrafo forviŝita',
	'diff_texte_ajoute' => 'Teksto aldonita',
	'diff_texte_deplace' => 'Teksto translokita',
	'diff_texte_supprime' => 'Teksto forviŝita',
	'differences_versions' => 'Diferencoj inter versio n-ro @id_version@ kaj versio n-ro @id_diff@',

	// I
	'icone_restaurer_version' => 'Restaŭri version n-ro @version@',
	'icone_suivi_revisions' => 'Superrigardo de revizioj',
	'info_1_revision' => '1 revizio',
	'info_aucune_revision' => 'Neniu revizio',
	'info_historique' => 'Revizioj :',
	'info_historique_lien' => 'Afiŝi historion pri modifoj',
	'info_historique_titre' => 'Superrigardo de revizioj',
	'info_nb_revisions' => '@nb@ revizioj',

	// L
	'label_choisir_id_version' => 'Elektu la versiojn komparotajn :',
	'label_config_revisions_objets' => 'Aktivigi la reviziojn ĉe la jenaj objektoj :',

	// M
	'message_valider_recuperer_version' => 'Validigi la formularon por restarigi tiun version.',

	// O
	'objet_editorial' => 'objekto',

	// P
	'plugin_update' => 'Ĝisdatigo de la kromprogramo „Revizioj“ al versio @version@.',

	// T
	'titre_form_revisions_objets' => 'Aktivigi la reviziojn',
	'titre_restaurer_version' => 'Restaŭri version',
	'titre_revisions' => 'Revizioj',

	// V
	'version_deplace_rubrique' => 'Transloki de <b>« @from@ »</b> al <b>« @to@ »</b>.',
	'version_initiale' => 'Komenca versio',
	'voir_differences' => 'Vidu la diferencojn',
	'voir_mes_revisions' => 'Miaj revizioj',
	'voir_revisions' => 'Vidi la reviziojn (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Ĉiuj revizioj'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Vidi la diferencojn',

	// D
	'diff_para_ajoute' => 'Paragrafo aldonita',
	'diff_para_deplace' => 'Paragrafo translokita',
	'diff_para_supprime' => 'Paragrafo forviŝita',
	'diff_texte_ajoute' => 'Teksto aldonita',
	'diff_texte_deplace' => 'Teksto translokita',
	'diff_texte_supprime' => 'Teksto forviŝita',
	'differences_versions' => 'Diferencoj inter versio n-ro @id_version@ kaj versio n-ro @id_diff@',

	// I
	'icone_restaurer_version' => 'Restaŭri version n-ro @version@',
	'icone_suivi_revisions' => 'Superrigardo de revizioj',
	'info_1_revision' => '1 revizio',
	'info_aucune_revision' => 'Neniu revizio',
	'info_historique' => 'Revizioj :',
	'info_historique_lien' => 'Afiŝi historion pri modifoj',
	'info_historique_titre' => 'Superrigardo de revizioj',
	'info_nb_revisions' => '@nb@ revizioj',

	// L
	'label_choisir_id_version' => 'Elektu la versiojn komparotajn :',
	'label_config_revisions_objets' => 'Aktivigi la reviziojn ĉe la jenaj objektoj :',

	// M
	'message_valider_recuperer_version' => 'Validigi la formularon por restarigi tiun version.',

	// O
	'objet_editorial' => 'objekto',

	// P
	'plugin_update' => 'Ĝisdatigo de la kromprogramo „Revizioj“ al versio @version@.',

	// T
	'titre_form_revisions_objets' => 'Aktivigi la reviziojn',
	'titre_restaurer_version' => 'Restaŭri version',
	'titre_revisions' => 'Revizioj',

	// V
	'version_deplace_rubrique' => 'Transloki de <b>« @from@ »</b> al <b>« @to@ »</b>.',
	'version_initiale' => 'Komenca versio',
	'voir_differences' => 'Vidu la diferencojn',
	'voir_mes_revisions' => 'Miaj revizioj',
	'voir_revisions' => 'Vidi la reviziojn (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Ĉiuj revizioj',
];
